<?php

namespace Assetdocs\Department\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Department\Interfaces\DepartmentRepositoryInterface;

class DepartmentController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Department\Interfaces\DepartmentRepositoryInterface $department
     *
     * @return type
     */
    public function __construct(DepartmentRepositoryInterface $department)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $department;
        parent::__construct();
    }

    /**
     * Show department's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $departments = $this->repository
            ->pushCriteria(new \Assetdocs\Department\Repositories\Criteria\DepartmentPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('department::public.department.index', compact('departments'))->render();
    }

    /**
     * Show department.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $department = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('department::public.department.show', compact('department'))->render();
    }
}
